<?php

/**
 * @file
 * Import photos and other data from Gallery2.
 *
 * Extend g2migrate/galler2.inc by adding migrations that use the Media
 * (7.x-1.x) module.
 */

/**
 * The moment you have been waiting for: import those photos.
 *
 * This class handles photos attached using the Media module.
 *
 * Tested with Media module 7.x-1.2.
 */
class Gallery2Media1ImageMigration extends Gallery2BaseMigration {
  public function __construct() {
    parent::__construct();
    $this->description = t('Create Media fields from Gallery2 photos.');

    // In the simplest case, just pass the media type.
    $this->destination = new MigrateDestinationMedia('image');

    $this->map = new MigrateSQLMap($this->machineName,
      array(
        'g_id' => array(
          'description' => 'size was 11',
          'type' => 'int',
          'size' => 'big',
          'not null' => TRUE,
          'alias' => 'e',
        ),
      ),
      MigrateDestinationMedia::getKeySchema()
    );

    // The source images are in a local directory - specify the parent.
    $this->addFieldMapping('source_dir')
        ->defaultValue(variable_get('g2migrate_g2data') . '/albums');
    // The 'value' of the media destination is mapped to the source field
    // representing the media itself - in this case, a filename relative to
    // source_dir.
    $this->addFieldMapping('value', 'path');
    // // Fields on the entity can be mapped in the usual way.
    // $this->addFieldMapping('field_image_description', 'description')
    //      ->xpath('description');
    $this->addFieldMapping('media_title', 'g_title');
    $this->addFieldMapping('media_description', 'g_summary');
    $this->addFieldMapping('field_tags', 'g_keywords');
    $this->addFieldMapping('field_tags:create_term')
      ->defaultValue(TRUE);

    $this->addFieldMapping('uid')
         ->defaultValue(1);

    // TODO: It might be nice to add these fields to the Media FileField entity.
    // For now, ignore them and add them to node in a dependent migration.
    $this->addUnmigratedSources(array('g_parentid'));

    $this->addUnmigratedDestinations(
      array(
        'timestamp',
        'media_title:format',
        'media_title:language',
        'media_description:format',
        'media_description:language',
        'field_tags:source_type',
        'field_license',
        'destination_dir',
        'destination_file',
        'file_replace',
        'preserve_files',
      )
    );
    if (module_exists('path')) {
      $this->addUnmigratedDestinations(array('path'));
  }

  }
}

/**
 * The moment you have been waiting for: import those photos.
 *
 * This class creates nodes from photos imported from Gallery2. The only
 * difference from Gallery2NodeMigration is that the photos are stored as Media
 * fields instead of Image fields.
 *
 * TODO: Analyze the difference between this class and Gallery2NodeMigration and
 * remove duplicated code.
 *
 * Tested with Media module 7.x-1.2.
 */
class Gallery2Media1NodeMigration extends Gallery2BaseMigration {
  public function __construct() {
    parent::__construct();
    $this->description = t('Create nodes and attach photos as Media FileFields.');

    $this->dependencies = array('Gallery2Album');

    $this->map = new MigrateSQLMap($this->machineName,
      array(
        'g_id' => array(
          'description' => 'size was 11',
          'type' => 'int',
          'size' => 'big',
          'not null' => TRUE,
          'alias' => 'e',
        ),
      ),
      MigrateDestinationNode::getKeySchema()
    );

    // Do not promote to the front page, and do not make sticky.
    $this->addFieldMapping('promote')
      ->defaultValue(0);
    $this->addFieldMapping('sticky')
      ->defaultValue(0);

    $node_type = variable_get('g2migrate_node_type', 'g2migrate_photo');
    $this->destination = new MigrateDestinationNode($node_type);

    $field = variable_get('g2migrate_field_path', 'g2migrate_image');
    $tags = variable_get('g2migrate_field_g_keywords', 'g2migrate_keywords');
    $title = variable_get('g2migrate_field_g_title', 'title');
    $body = variable_get('g2migrate_field_g_summary', 'body');
    $vocabulary = variable_get('g2migrate_field_g_parentid', 'g2migrate_album');

    $this->addFieldMapping($field, 'path');
    $this->addFieldMapping("$field:source_dir")
      ->defaultValue(variable_get('g2migrate_g2data') . '/albums');
    $this->addFieldMapping($title, 'g_title');
    $this->addFieldMapping($body, 'g_summary');
    $this->addFieldMapping('uid')
      ->defaultValue(1);
    $this->addFieldMapping($vocabulary, 'g_parentid')
      ->sourceMigration('Gallery2Album');
    $this->addFieldMapping("$vocabulary:source_type")
      ->defaultValue('tid');
    $this->addFieldMapping($tags, 'g_keywords')
      ->separator(',');
    $this->addFieldMapping("$tags:create_term")
      ->defaultValue(TRUE);

    $this->addUnmigratedDestinations(
      array(
        'created',
        'changed',
        'status',
        'revision',
        'log',
        'language',
        'tnid',
        'revision_uid',
        'is_new',
        "$body:summary",
        "$body:format",
        "$body:language",
        "$vocabulary:create_term",
        "$tags:source_type",
        'comment',
      )
    );

    if (module_exists('path')) {
      $this->addFieldMapping('path')
           ->issueGroup(t('DNM'));
      if (module_exists('pathauto')) {
        $this->addFieldMapping('pathauto')
             ->issueGroup(t('DNM'));
      }
    }
    if (module_exists('statistics')) {
      $this->addUnmigratedDestinations(array('totalcount', 'daycount', 'timestamp'));
    }

  }
}
